[PATCH try2] Improve error output of git-rebase

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



"git rebase" without arguments on initial startup showed:

	fatal: Needed a single revision
	invalid upstream

This patch makes it show the ordinary usage string.

If .git/rebase-apply exists, this patch tries to make the error message
slightly more exact:
 - if .git/rebase-apply/applying exists, the error message supposes that
   we are in the middle of git-am
 - if .git/rebase-apply/rebasing exists, it is perhaps another rebase.

Signed-off-by: Stephan Beyer <s-beyer@xxxxxxx>
---
	Hi,

	Junio C Hamano wrote:
	> Stephan Beyer <s-beyer@xxxxxxx> writes:
	>~
	> > ^...Stumbled across this today and looks for me like
	> > ^...a patch for 1.6.0 :-)
	>~
	> Is presense of "$dotest" or "$GIT_DIR/rebase-apply" a _sure sign_ that
	> allows you to say "A rebase is in progress" with confidence?

	Currently this is a sure sign that either a git-rebase or a git-am is
	in progress.
	I considered the existence of .git/rebase-apply/applying and
	.git/rebase-apply/rebasing as a good way to determine which one it is
	if .git/rebase-apply exists.

	Also there already are two error messages that could be used, so I
	use them and are only a little more exact.

	Regards,
	  Stephan

 git-rebase.sh |   23 ++++++++++++++++-------
 1 files changed, 16 insertions(+), 7 deletions(-)

diff --git a/git-rebase.sh b/git-rebase.sh
index 412e135..850c58a 100755
--- a/git-rebase.sh
+++ b/git-rebase.sh
@@ -146,6 +146,10 @@ is_interactive () {
 
 is_interactive "$@" && exec git-rebase--interactive "$@"
 
+# If no arguments are given and there is no git-am/git-rebase in
+# progress, print the usage string and die.
+test $# -ne 0 -o -d "$dotest" -o -d "$GIT_DIR"/rebase-apply || usage
+
 while test $# != 0
 do
 	case "$1" in
@@ -265,19 +269,24 @@ do
 	shift
 done
 
 # Make sure we do not have $GIT_DIR/rebase-apply
 if test -z "$do_merge"
 then
-	if mkdir "$GIT_DIR"/rebase-apply
+	if mkdir "$GIT_DIR"/rebase-apply 2>/dev/null
 	then
 		rmdir "$GIT_DIR"/rebase-apply
 	else
+		what='a patch application or another rebase.'
+		test -f "$GIT_DIR"/rebase-apply/applying &&
+			what='a patch application (git-am).'
+		test -f "$GIT_DIR"/rebase-apply/rebasing &&
+			what='another rebase.'
 		echo >&2 '
-It seems that I cannot create a '"$GIT_DIR"'/rebase-apply directory,
-and I wonder if you are in the middle of patch application or another
-rebase.  If that is not the case, please
+It seems that I cannot create a rebase-apply directory, and I wonder
+if you are in the middle of '"$what"'
+If that is not the case, please
 	rm -fr '"$GIT_DIR"'/rebase-apply
- and run me again.  I am stopping in case you still have something
+and run me again.  I am stopping in case you still have something
 valuable there.'
 		exit 1
 	fi
@@ -285,7 +294,7 @@ else
 	if test -d "$dotest"
 	then
 		die "previous rebase directory $dotest still exists." \
-			'try git-rebase < --continue | --abort >'
+			'Try git-rebase (--continue | --abort | --skip)'
 	fi
 fi
 
@@ -265,19 +269,24 @@ do
 done
 
-# Make sure we do not have $GIT_DIR/rebase-apply
+# Make sure we do not have $GIT_DIR/rebase-apply nor $dotest
 if test -z "$do_merge"
 then
-- 
1.6.0.rc3.312.ge6010a

--
To unsubscribe from this list: send the line "unsubscribe git" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Linux Kernel Development]     [Gcc Help]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [V4L]     [Bugtraq]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]     [Fedora Users]

  Powered by Linux